/**
 * @flow
 */
import React from 'react';
import { View, ScrollView,
} from 'react-native';
import FastImage from 'react-native-fast-image';
import { FlatGrid } from 'react-native-super-grid';
import Text from '../../components/Text';
import SwiperView from '../../components/Swiper';

/**
 *
 首页
 type  0     轮播图
 type  1     九宫格
 type  2     活动
 type  3     商品

 服务

 type  4  最近使用
 type  5  标题
 type  6  九宫格
 type  7  图片展示
 type  8  公司名字九宫格
 type  9  轮播图

 我的
 type 10  3列九宫格
 type 11  带标题4列的九宫格
 type 12  icon+title       >
 * @type {number}
 */
const BANNER = 0;
const GRID = 1;
const ACTIVITY = 2;
const EXTRASRV = 3;

export function swiperItem(data) {
  const swiperHeight = data.width / 2.7;
  console.log('width:', data.width, swiperHeight);
  return (
    data.data.map((item, index) => (
      <View
        key={`${item.imgUrl}${index}`}
        style={{
          width: data.width,
          height: swiperHeight,
          paddingHorizontal: 10,
          paddingTop: 10,
        }}
      >
        <FastImage
          style={{ width: data.width - 20, height: swiperHeight - 10 }}
          source={{
            uri: item.imgUrl,
            priority: FastImage.priority.normal,
          }}
          resizeMode={FastImage.resizeMode.stretch}
        />
      </View>
    ))
  );
}

export function renderBanner(props) {
  console.log('renderBanner', props);
  return (
    <View
      key="SwiperView"
      style={{
        height: props.height,
      }}
    >
      <SwiperView
        height={props.height}
        width={props.width}
      >
        {swiperItem(props)}
      </SwiperView>
    </View>
  );
}

export function renderGrid(props) {
  const gridwidth = ((props.width) / 4);
  console.log('renderGrid:', gridwidth);
  return (
    <FlatGrid
      itemDimension={gridwidth}
      items={props.data}
      spacing={0}
      renderItem={({ item,index }) => (
        <View
          key={`${index}${item.imgUrl}`}
          style={{
            width: gridwidth - 1,
            justifyContent: 'center',
            alignItems: 'center',
            marginVertical: 10,
          }}
        >
          <FastImage
            style={{ width: 36, height: 36 }}
            source={{
              uri: item.imgUrl,
              priority: FastImage.priority.normal,
            }}
            resizeMode={FastImage.resizeMode.stretch}
          />
          <Text
            style={{
              fontSize:14,
              color:'#333',
              marginTop:5,
            }}
          >
            {item.title}
          </Text>
        </View>
      )}
    />
  );
}

export function activityItem(item) {
  return (
    <View
      style={{
        width: 192,
        alignItems: 'stretch',
        marginLeft: 10,
      }}
    >
      <FastImage
        style={{ width: 192, height: 108 }}
        source={{
          uri: item.imgUrl,
          priority: FastImage.priority.normal,
        }}
        resizeMode={FastImage.resizeMode.stretch}
      />
      <Text
        style={{
          fontSize: 16,
          marginTop: 8,
          fontColor: '#20253C',
        }}
      >
        {item.title}
      </Text>
      <Text
        style={{
          fontSize: 14,
          marginVertical: 8,
          color: item.detailColor,
        }}
        numberOfLines={2}
      >
        {item.detail}
      </Text>
    </View>
  );
}

export function renderTitle(title,marginLeft?) {
  return (
    <View>
      <Text
        style={{
          fontSize: 18,
          marginLeft: marginLeft || 10,
          marginTop: 10,
          fontColor: '#20253C',
        }}
      >
        {title}
      </Text>
    </View>
  );
}

export function renderActivity(props) {
  return (
    <View>
      {
        renderTitle(props.title)
      }
      <ScrollView
        style={{
          marginVertical: 14,
          width: props.width,
          height: 176,
        }}
        horizontal
        showsHorizontalScrollIndicator={false}
      >
        {props.data.map((item, index) => (
          activityItem(item)
        ))
        }
      </ScrollView>
    </View>
  );
}


export function renderExtraSrv(props) {
  return (
    <View>
      {
        renderTitle(props.title)
      }
      <ScrollView
        style={{
          marginVertical: 14,
          width: props.width,
        }}
        horizontal
        showsHorizontalScrollIndicator={false}
      >
        {props.data.map((item, index) => (
          <FastImage
            style={{
              width: 122,
              height: 130,
              marginLeft: 10,
            }}
            source={{
              uri: item.imgUrl,
              priority: FastImage.priority.normal,
            }}
            resizeMode={FastImage.resizeMode.stretch}
          />
        ))
        }
      </ScrollView>
    </View>
  );
}

export function renderByType(type) {
  switch (type) {
  case BANNER:
    return renderBanner;
  case GRID:
    return renderGrid;
  case ACTIVITY:
    return renderActivity;
  case EXTRASRV:
    return renderExtraSrv;
  default:
    return () => {
    };
  }
}

export default {};
